# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Added
- ???
- ???

### Changed
- ???

### Fixed
- ???

## [0.0.1] - 2024-09-15
### Added
- Initial release with just the library logo.
